==> 1.0.16.tar.gz: website/content/post/2024-10-12-PaulBSD-updates-october-24.md <==
+++
categories = ["Services", "Fun", "Thailand", "FOSDEM"]
date = "2024-10-12"
menu = ""
tags = ["paulbsd", "fun", "services", "fosdem2025", "life", "edm"]
title = "PaulBSD October '24 updates"
+++

# PaulBSD October '24 updates

Here are some news about me and my platform

## Current plaform tools

ipbl / ipblc / k8s / dip / etc. -> business as usual

## DNS

I'm currently serving requests of domains I own using dnsdist / powerdns / gdnsd.
Those tools are awesome because powerful, pluggable and are coming with great out-of-the-box features.

# Life

## Thailand

I went to Thailand in August, it's the farest, greatest trip of my life. I'll certainly go back soon.
This country is just 😍, only the plane trip is aweful (around 11h without stop to 15h and more with stop)

## FOSDEM 2025

On the next year FOSDEM will occur on 1 & 2 February 2025, I will certainly go to Brussel 'One More Time' 😜 to see very interesting conferences, eat Belgian fries with Mayonnaise and drink some beer.

## Music

My vinyl flightcase is full (I have now a new one). I now have dozens of EPs and LPs.
I will have to buy a new turntable, my current one is a Reloop RP 2000 (cheap model, but really quality made from my point of view)
A mixer would be required there, I need to find one at some point.
Records I own are mostly French / European / American House, Deep and Disco, from '70 to nowadays, see @paulbsd89 on IG if you want to see them !

## NDK Festival

As of writing, NDK festival takes place in Caen (FR) and so many DJs are performing some EDM.
Don't be so drunk and take care

==> 1.0.17.tar.gz: website/content/post/2024-10-12-PaulBSD-updates-october-24.md <==
+++
categories = ["Services", "Fun", "Thailand", "FOSDEM"]
date = "2024-10-12"
menu = ""
tags = ["paulbsd", "fun", "services", "fosdem2025", "life", "edm"]
title = "PaulBSD October '24 updates"
+++

# PaulBSD October '24 updates

Here are some news about me and my platform

## Current plaform tools

ipbl / ipblc / k8s / dip / etc. -> business as usual

## DNS

I'm currently serving requests of domains I own using dnsdist / powerdns / gdnsd.
Those tools are awesome because powerful, pluggable and are coming with great out-of-the-box features.

# Life

## Vacations

I went to Thailand in August, it's the farest, greatest trip of my life. I'll certainly go back soon.
This country is just awesome, only the plane trip is aweful (around 11h without stop to 15h and more with stop)

## FOSDEM 2025

On the next year FOSDEM will occur on 1 & 2 February 2025, I will certainly go to Brussel to see very interesting conferences, eat Belgian fries with Mayonnaise and drink some beer.

## Music

My vinyl flightcase is full (I have now a new one). I now have dozens of EPs and LPs.
I will have to buy a new turntable, my current one is a Reloop RP 2000 (cheap model, but really quality made from my point of view)
A mixer would be required there, I need to find one at some point.
Records I own are mostly French / European / American House, Deep and Disco, from '70 to nowadays, see @paulbsd89 on IG if you want to see them !

## NDK Festival

As of writing, NDK festival takes place in Caen (FR) and so many DJs are performing some EDM.
Don't be so drunk and take care
